jvcprojectorcontrol

package module
v0.0.0-...-79adad4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 19, 2025 License: MIT Imports: 7 Imported by: 0

README

JVC Projector Remote Control Library

This package provides the ability to remotely control a JVC Projector via TCP/IP.

It provides both a Go library that can be used by other applications, as well as a stand alone command line tool that can be used directly.

JVC Projector Setup

The JVC Projector must be connected to your local network using an Ethernet cable.

In the projector, you must enable the LAN communication and (if applicable) set the Communication Terminal to LAN (only for projectors with RS232 ports)

For NZ projectors, a password must be set that is between 8 and 10 characters in length and must be used when connecting to the projector.

The NZ500/700 requires the password to be hashed.

NX projectors do not require a password.

Commands

Currently Supported Commands:

  • NULL - Test command to verify connectivity.
  • OFF - Turn Projector off
  • ON - Turn Projector on
  • Input1 - Select Input 1
  • Input2 - Select Input 2

Additional commands can be added easily once you have the correct bytes required from the documentation.

Docs:

Command Line

The command line tool takes several arguments.

-i <IP Address> Specify the IP address of the projector (if known)

-s Scan subnet for projectors. Will send the command if one found, or return a list of IPs if multiple are found.

Command: (-c NULL)

  • NULL
  • OFF
  • ON
  • INPUT1
  • INPUT2

-p <PASSWORD> Specify the password (NZ projectors)

Password Hash: (-h NONE)

  • NONE - For NX projectors
  • JVCKW - For most NZ projectors
  • JVCKWPJ For NZ500/NZ700 and later projectors

-d enabled debug mode to see all traffic to/from the projector.

Resources

Similar Projects

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ScanForProjectors

func ScanForProjectors(debug bool) []string

Types

type Command

type Command int
const (
	NullCommand Command = iota
	OffCommand
	OnCommand
	Input1Command
	Input2Command
)

type HashMode

type HashMode int
const (
	HashNone HashMode = iota
	HashJVCKW
	HashJVCKWPJ
)

type Projector

type Projector struct {
	IPAddress string
	Password  string
	Hash      HashMode
	Debug     bool
}

func NewProjector

func NewProjector(ipAddress, password string, hash HashMode, debug bool) *Projector

func (*Projector) SendCommand

func (p *Projector) SendCommand(c Command) error

Directories

Path Synopsis
cmd
cli command

Jump to